==> models_base-1.4.0.tar.gz: CHANGELOG.md <==
### 1.4.0

same 
### 1.3.9

quick extension spend/quickSpend until a genuine new tickettype comes in

### 1.3.7
http back to 0.13.4

### 1.3.6
yup -> mobileMoney

### 1.3.5
cool stuff

### 1.3.4
http: ^0.12.0 #^0.13.4

### 1.3.3
lower collection version

### 1.3.2
address zipCode easier

### 1.3.1
no string address in contact

### 1.3.0
- article basket and loads of clean
- remove price/cost from ArticleAbstract
### 1.2.6
- make basket an interface
### 1.2.5
- pubignore + onepub

### 1.2.4
- proxy is clear enough

### 1.2.3
- proxies_worth != proxies

### 1.2.2
- lot was too proxy-mative a name

### 1.2.1
- ItemInCartAbstract

### 1.2.0
- finalize it

### 1.1.9
- more constant classes
- Item -> CartItem

### 1.1.8
- added empty fields for Address and Country to avoid null

### 1.1.7
- added Address
### 1.1.6
- added Country

### 1.1.5
- reworked unit tests

### 1.1.4
- passe updateDate in LineArticle && Article

### 1.1.3
- lot default -> status

### 1.1.2
- DbStoresBase.products -> DbStoresBase.articles
- db name products => articles

### 1.1.1
- Product->ArticleLine
- remove Qt from Lot which was confusing

### 1.1.0
- added equality

### 1.0.9
- added const Environment.custom(this._env);

### 1.0.8
- added endpoint_base

### 1.0.7
- removed StockQuantity

## 1.0.6
- removed that stupid manager store

## 1.0.5

- finals
## 1.0.4

- same thing really
## 1.0.3

- remodelled statusUpdateDate in ticket model
## 1.0.2

- removed extensions and moved them somewhere else
## 1.0.1

- open v
## 1.0.0

- Initial version.

==> models_base-1.4.4.tar.gz: CHANGELOG.md <==
### 1.4.3

photos in a dedicated class

### 1.4.2

intl: ^0.18.0

### 1.4.1

intl: ^0.18.1

### 1.3.9

quick extension spend/quickSpend until a genuine new tickettype comes in

### 1.3.7
http back to 0.13.4

### 1.3.6
yup -> mobileMoney

### 1.3.5
cool stuff

### 1.3.4
http: ^0.12.0 #^0.13.4

### 1.3.3
lower collection version

### 1.3.2
address zipCode easier

### 1.3.1
no string address in contact

### 1.3.0
- article basket and loads of clean
- remove price/cost from ArticleAbstract
### 1.2.6
- make basket an interface
### 1.2.5
- pubignore + onepub

### 1.2.4
- proxy is clear enough

### 1.2.3
- proxies_worth != proxies

### 1.2.2
- lot was too proxy-mative a name

### 1.2.1
- ItemInCartAbstract

### 1.2.0
- finalize it

### 1.1.9
- more constant classes
- Item -> CartItem

### 1.1.8
- added empty fields for Address and Country to avoid null

### 1.1.7
- added Address
### 1.1.6
- added Country

### 1.1.5
- reworked unit tests

### 1.1.4
- passe updateDate in LineArticle && Article

### 1.1.3
- lot default -> status

### 1.1.2
- DbStoresBase.products -> DbStoresBase.articles
- db name products => articles

### 1.1.1
- Product->ArticleCalibre
- remove Qt from Lot which was confusing

### 1.1.0
- added equality

### 1.0.9
- added const Environment.custom(this._env);

### 1.0.8
- added endpoint_base

### 1.0.7
- removed StockQuantity

## 1.0.6
- removed that stupid manager store

## 1.0.5

- finals
## 1.0.4

- same thing really
## 1.0.3

- remodelled statusUpdateDate in ticket model
## 1.0.2

- removed extensions and moved them somewhere else
## 1.0.1

- open v
## 1.0.0

- Initial version.
